@@ -20,9 +20,8 @@ class Robot:
         self.thread.start()
 
         ready_event.wait()
-
-        self.__communication_manager.get_configuration()
-        self.__configuration = self.__communication_manager.get_configurations()
+        
+        self.__configuration = self.__communication_manager.get_configuration()
 
         # if it is required to wait for a green light from the server in order to run the code, wait.
         if "wait_for_game_start" in self.__configuration and self.__configuration["wait_for_game_start"]:
